@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 
-from appkit import App
+from appkit.api.v0_2_4 import App
 import os
 import sys
 from jinja2 import Template
+import codecs
 
 
-app = App(app_path=os.path.dirname(__file__))
+app = App(__file__)
 
 try:
     file_name = sys.argv[1]
@@ -20,11 +21,11 @@ app.file_name = file_name
 
 @app.route('/$')
 def index():
-    ui_path = os.path.join(app.app_path, 'ui.html')
+    ui_path = os.path.join(app.app_dir, 'ui.html')
     template = Template(open(ui_path).read())
     markdown = None
     if app.file_name is not None:
-        markdown = open(file_name).read()
+        markdown = codecs.open(file_name, 'r', 'utf-8').read()
     return template.render(file_name=app.file_name, text=markdown)
 
 
